@@ -27,6 +27,10 @@ CHANGELOG = ChangeLog(
     Version('0.3.2',
         'Added contexts',
         ),
+    Version('0.3.3',
+        'Added greater support for code coverage',
+        'Fixed numerous bugs via code coverage'
+        ),
 )
 
 __doc__ += '\n' + str(CHANGELOG)
